@@ -2,17 +2,19 @@
 ## PLOT A REPRESENTATIVE SEQUENCE
 ## ==============================
 
-plot.stslist.rep <- function(x, cpal=NULL, missing.color=NULL,
-	pbarw=TRUE, dmax=NULL, stats=TRUE,
-	ylab=NULL, xaxis=TRUE, xtlab=NULL, xtstep=NULL, cex.plot=1, ...) {
+plot.stslist.rep <- function(x, cpal = NULL, missing.color = NULL, pbarw = TRUE,
+  dmax = NULL, stats = TRUE, ylab = NULL, xaxis = TRUE, xtlab = NULL,
+  xtstep = NULL, cex.with.axis = 1, cex.plot, ...) {
+
+  checkargs(alist(cex.with.axis = cex.plot))
 
 	## Extracting attributes
 	n <- attr(x,"nbseq")
-	
+
 	if (is.null(xtlab)) {xtlab <- colnames(x)}
 
 	if (is.null(xtstep)) {
-		if (!is.null(attr(x,"xtstep"))) {xtstep <- attr(x,"xtstep")} 
+		if (!is.null(attr(x,"xtstep"))) {xtstep <- attr(x,"xtstep")}
 		## For sequence objects created with previous versions
 		else {xtstep <- 1}
 	}
@@ -60,14 +62,14 @@ plot.stslist.rep <- function(x, cpal=NULL, missing.color=NULL,
 	dist.scaling <- dmax/seql
 
 	## space between text lines
-	vspace <- 0.1	
+	vspace <- 0.1
 
 	## Space between seq bars
 	if ("space" %in% names(olist)) space <- olist[["space"]]
 	else space <- 0.2
 
-	## 
-	if (pbarw) 
+	##
+	if (pbarw)
 		barw <- Statistics$"na(%)"[1:nbrep]/100
 	else barw=1
 
@@ -94,27 +96,27 @@ plot.stslist.rep <- function(x, cpal=NULL, missing.color=NULL,
 	if (xaxis) {
 		tpos <- seq(1,seql, xtstep)
 
-		axis(1, at=tpos-0.5, labels=xtlab[tpos], 
-			pos=-0.04, 
-			## mgp=c(.5,.5,0), 
-			cex.axis=cex.plot)
+		axis(1, at=tpos-0.5, labels=xtlab[tpos],
+			pos=-0.04,
+			## mgp=c(.5,.5,0),
+			cex.axis=cex.with.axis)
 	}
 
 	## y (percents) axis
 
 	## y.lab.pos <- c(space*mean(barw),(1+(nrow(x)*space*mean(barw))))
 
-	## axis(2, at=y.lab.pos, 
-	##	labels=c("0%", "100%"), 
-	##	las=1, 
-	##	cex.axis=cex.plot)
+	## axis(2, at=y.lab.pos,
+	##	labels=c("0%", "100%"),
+	##	las=1,
+	##	cex.axis=cex.with.axis)
 
 	## Frequency of the representative sequence
 	nbprox <- sum(Statistics$nb[1:nbrep])
 	ctfreq <- round((nbprox/n)*100,1)
-	text(seql/2, 1.3, 
-		paste("Criterion=",ctname,", coverage=", ctfreq ,"%", sep=""), 
-		cex=cex.plot)
+	text(seql/2, 1.3,
+		paste("Criterion=",ctname,", coverage=", ctfreq ,"%", sep=""),
+		cex=cex.with.axis)
 
 	## ==========
 	## Statistics
@@ -130,32 +132,32 @@ plot.stslist.rep <- function(x, cpal=NULL, missing.color=NULL,
 		## Symbols for the representative sequences
 		spval <- space/nbrep
 		y.lab.pos <- (barw[1]/2)+spval
-		lines(-1, y.lab.pos, type="b", pch=repsymb[1], lwd=3, 
-			col=repcol[1], cex=cex.plot+barw[1])
+		lines(-1, y.lab.pos, type="b", pch=repsymb[1], lwd=3,
+			col=repcol[1], cex=cex.with.axis+barw[1])
 		for (p in 2:nbrep) {
 			y.lab.pos <- sum(barw[1:p-1])+(p*spval)+(barw[p]/2)
-			lines(-1, y.lab.pos, type="b", pch=repsymb[p], lwd=3, 
-				col=repcol[p], cex=cex.plot+barw[p])
-		}	
-	
+			lines(-1, y.lab.pos, type="b", pch=repsymb[p], lwd=3,
+				col=repcol[p], cex=cex.with.axis+barw[p])
+		}
+
 		## Distance to representative seq.
-		dist.rep.pos <- y.sym.pos	
+		dist.rep.pos <- y.sym.pos
 
 		for (i in 1:nbrep) {
-			lines(Statistics$MD[i]/dist.scaling, dist.rep.pos, 
+			lines(Statistics$MD[i]/dist.scaling, dist.rep.pos,
 				type="b", pch=repsymb[i], lwd=3, col=repcol[i], cex=1+barw[i])
 		}
 
 		legend.B <- paste("(B) Mean dist. to representative seq.", sep="")
-	
+
 		## Distance to center
 		y.sym.pos <- y.sym.pos + 2*vspace
 		dist.center.pos <- y.sym.pos
 
 		for (i in 1:nbrep) {
-			lines(Statistics$V[i]/dist.scaling, 
-				y.sym.pos, 
-				type="b", pch=repsymb[i], lwd=3, col=repcol[i], cex=cex.plot+barw[i])
+			lines(Statistics$V[i]/dist.scaling,
+				y.sym.pos,
+				type="b", pch=repsymb[i], lwd=3, col=repcol[i], cex=cex.with.axis+barw[i])
 		}
 
 		legend.A <- paste("(A) Discrepancy (mean dist. to center)",sep="")
@@ -163,24 +165,24 @@ plot.stslist.rep <- function(x, cpal=NULL, missing.color=NULL,
 		## Axis for the boxplot of distances to the representative sequences
 		dypos <- 1.7
 
-		nbdec <- if (dmax>=4) 0 else 1  
-		
-		axis(1, at=seq(0,seql,seql/4), 
-			labels=round(seq(0,dmax,dmax/4),nbdec), 
-			pos=dypos, mgp=c(.5,.5,0), 
-			cex.axis=cex.plot)
-		
-		axis(2, at=c(dist.rep.pos,dist.center.pos), 
-			labels=c("B","A"), 
-			las=2, 
-			cex.axis=cex.plot)
+		nbdec <- if (dmax>=4) 0 else 1
+
+		axis(1, at=seq(0,seql,seql/4),
+			labels=round(seq(0,dmax,dmax/4),nbdec),
+			pos=dypos, mgp=c(.5,.5,0),
+			cex.axis=cex.with.axis)
+
+		axis(2, at=c(dist.rep.pos,dist.center.pos),
+			labels=c("B","A"),
+			las=2,
+			cex.axis=cex.with.axis)
 
 		legend(seql/2, ymax, legend=c(legend.A, legend.B),
 			xjust=0.5,
 			yjust=0.7,
-			## title="Distance", 
+			## title="Distance",
 			box.lty=0,
-			cex=cex.plot)
+			cex=cex.with.axis)
 	}
 }
 
