@@ -2,8 +2,11 @@
 ## PLot of the state distribution
 ## ==============================
 
-plot.stslist.statd <- function(x, type="d", cpal=NULL, ylab=NULL, yaxis=TRUE, xaxis=TRUE, xtlab=NULL, xtstep=NULL, 
-	cex.plot=1, space=0, ...) {
+plot.stslist.statd <- function(x, type = "d", cpal = NULL, ylab = NULL,
+  yaxis = TRUE, xaxis = TRUE, xtlab = NULL,xtstep = NULL, cex.axis = 1,
+  space = 0, xlab = NULL, cex.plot, ...) {
+
+  checkargs(alist(cex.axis = cex.plot))
 
 	n <- attr(x,"nbseq")
 	weighted <- attr(x, "weighted")
@@ -13,27 +16,27 @@ plot.stslist.statd <- function(x, type="d", cpal=NULL, ylab=NULL, yaxis=TRUE, xa
 	if (is.null(xtlab)) {xtlab <- attr(x,"xtlab")}
 
 	if (is.null(xtstep)) {
-		if (!is.null(attr(x,"xtstep"))) {xtstep <- attr(x,"xtstep")} 
+		if (!is.null(attr(x,"xtstep"))) {xtstep <- attr(x,"xtstep")}
 		## For sequence objects created with previous versions
 		else {xtstep <- 1}
 	}
 
 	seql <- length(xtlab)
 
-	## State distribution plot	
+	## State distribution plot
 	if (type=="d") {
 		if (is.null(cpal))
 			cpal <- attr(x,"cpal")
 
-		if (is.null(ylab)) 
+		if (is.null(ylab))
 			ylab <- paste("Freq. (",wlab,"n=",round(n,2),")",sep="")
 
 		barplot(x$Frequencies,
 			space=space,
 			axes=FALSE,
 			axisnames=FALSE,
-			## cex.axis=cex.plot,
-			## cex.names=cex.plot,
+			## cex.axis=cex.axis,
+			## cex.names=cex.axis,
 			col=cpal,
 			ylab=ylab,
 			...)
@@ -47,34 +50,34 @@ plot.stslist.statd <- function(x, type="d", cpal=NULL, ylab=NULL, yaxis=TRUE, xa
 		}
 
 		if (xaxis) {
-			axis(1, at=x.lab.pos, labels=xtlab[tpos], pos=-0.02, cex.axis=cex.plot)
+			axis(1, at=x.lab.pos, labels=xtlab[tpos], pos=-0.02, cex.axis=cex.axis)
 		}
 	}
 	## Entropy index plot
 	else if (type=="Ht") {
-		if (is.null(ylab)) 
+		if (is.null(ylab))
 			ylab <- paste("Entropy index (",wlab,"n=",round(n,2),")",sep="")
-	
-		plot(x$Entropy, 
+
+		plot(x$Entropy,
 			col="blue",
 			## frame.plot=TRUE,
 			type="l",
-			lwd=3.5, 
-			lty="solid", 
+			lwd=3.5,
+			lty="solid",
 			axes=FALSE,
 			ylim=0:1,
 			ylab=ylab,
-			xlab=NA,
+			xlab=xlab,
 			...)
 
 		## Plotting the x axis
 		if (xaxis) {
 			tpos <- seq(1,seql, xtstep)
-			axis(1, at=tpos, labels=xtlab[tpos], pos=-0.02, cex.axis=cex.plot)
+			axis(1, at=tpos, labels=xtlab[tpos], pos=-0.02, cex.axis=cex.axis)
 		}
 	}
 
 	##
-	if (is.null(yaxis) || yaxis)	
-		axis(2, cex.axis=cex.plot)
+	if (is.null(yaxis) || yaxis)
+		axis(2, cex.axis=cex.axis)
 }
