@@ -1,14 +1,16 @@
 ###########################
 ## Locate the difference in sequence between groups
 ###########################
-seqdiff <- function(seqdata, group, cmprange=c(0, 1),
-					seqdist_arg=list(method="LCS", norm=TRUE),
-					with.missing=FALSE, weighted=TRUE, squared=FALSE) {
+seqdiff <- function(seqdata, group, cmprange = c(0, 1),
+  seqdist.args = list(method = "LCS", norm = TRUE), with.missing = FALSE,
+  weighted = TRUE, squared = FALSE, seqdist_arg) {
+
+  checkargs(alist(seqdist.args = seqdist_arg))
 
 	if (!inherits(seqdata, "stslist")) {
 			stop("seqdata should be a stslist, see seqdef")
 	}
-	seqdist_arg$with.missing <- with.missing
+	seqdist.args$with.missing <- with.missing
 	slenE <- ncol(seqdata)
 	ret <- NULL
 	startAt <- 1
@@ -29,7 +31,7 @@ seqdiff <- function(seqdata, group, cmprange=c(0, 1),
 	ret$discrepancy <- matrix(0, nrow=length(totrange), ncol=(num_column+1))
 	rownames(ret$discrepancy) <- colnames(seqdata)[totrange]
 	colnames(ret$discrepancy) <- c(name_column, "Total")
-	
+
 	weights <- attr(seqdata, "weights")
 	if (!weighted) {
 		weights <- NULL
@@ -54,9 +56,9 @@ seqdiff <- function(seqdata, group, cmprange=c(0, 1),
 		else {
 			seqok <- complete.cases(cmpbase)
 		}
-		seqdist_arg$seqdata <- subseq[seqok, ]
+		seqdist.args$seqdata <- subseq[seqok, ]
 		## Computing distance on range
-		sdist <- suppressMessages(do.call(seqdist, args=seqdist_arg))
+		sdist <- suppressMessages(do.call(seqdist, args=seqdist.args))
 		tmp <- dissassoc(sdist, cmpbase[seqok], R=0, weights=weights[seqok], weight.permutation="diss", squared=squared)
 		ret$stat[i,rownames(tmp$stat)] <- tmp$stat[,1]
 		ret$discrepancy[i,rownames(tmp$groups)] <- tmp$groups$discrepancy
@@ -79,8 +81,12 @@ print.seqdiff <- function(x, ...) {
 ###########################
 ## Plot method for seqdiff
 ###########################
-plot.seqdiff <- function(x, stat="Pseudo R2", type="l", ylab=stat, xlab="",
-							legendposition="top", ylim=NULL, xaxt=TRUE, col=NULL, xtstep=NULL, ...) {
+plot.seqdiff <- function(x, stat = "Pseudo R2", type = "l", ylab = stat,
+  xlab = "", legend.pos = "top", ylim = NULL, xaxis = TRUE, col = NULL,
+  xtstep = NULL, legendposition, xaxt, ...) {
+
+  checkargs(alist(legend.pos = legendposition, xaxis = xaxt))
+
 	if(is.null(xtstep)){
 		xtstep <- ifelse(!is.null(attr(x, "xtstep")), attr(x, "xtstep"), 1)
 	}
@@ -106,14 +112,14 @@ plot.seqdiff <- function(x, stat="Pseudo R2", type="l", ylab=stat, xlab="",
     		for (i in 1:(ncol(x$discrepancy)-1)) {
     			lines(toplot[, i], type=type, col=cpal[i], ...)
     		}
-    		legend(legendposition, fill = cpal, legend = colnames(x$discrepancy))
-			if(xaxt){
+    		legend(legend.pos, fill = cpal, legend = colnames(x$discrepancy))
+			if(xaxis){
 				tpos <- seq(1,nrow(x$discrepancy), xtstep)
 				axis(1, at=tpos-0.5, labels=rownames(x$stat)[tpos])
 			}
     		return(invisible())
     	}
-	
+
 	    ##if(length(stat)==1){
 		if(is.null(col)){
 			col <- c("black")
@@ -124,14 +130,14 @@ plot.seqdiff <- function(x, stat="Pseudo R2", type="l", ylab=stat, xlab="",
 		else {
 			stop(" [!] 'stat' argument should be one of ", paste(c("discrepancy", colnames(x$stat)), sep=", "), ".")
 		}
-		
+
 	}else if (length(stat)==2) {
 		if(sum(stat %in% colnames(x$stat)) < 2 ){
 			stop(" [!] The two values of the 'stat' argument should be one of ", paste(colnames(x$stat), sep=", "), ".")
 		}
         for (i in 1:2){
             if (!(stat[i] %in% colnames(x$stat))){
-          			
+
             }
         }
 		if(is.null(col)){
@@ -143,12 +149,12 @@ plot.seqdiff <- function(x, stat="Pseudo R2", type="l", ylab=stat, xlab="",
 		on.exit(par(oldpar))
 		plot(x$stat[, stat[2]],type=type,xlab="",ylab="", xaxt="n",col=col[2],axes=FALSE, ...)
 		axis(4,col=col[2],col.axis=col[2])
-		legend(legendposition, fill = col, legend =stat)
+		legend(legend.pos, fill = col, legend =stat)
 	}
 	else{
 		stop(" [!] Too many values for the 'stat' argument (max 2)")
 	}
-	if(xaxt){
+	if(xaxis){
 		tpos <- seq(1,nrow(x$discrepancy), xtstep)
 		axis(1, at=tpos-0.5, labels=rownames(x$stat)[tpos])
 	}
